@@ -14,9 +14,13 @@
 
 """Named constants used in YubiHSM commands."""
 
-from cryptography.hazmat.primitives.asymmetric import ec
-from cryptography.hazmat.primitives import hashes
 from enum import IntEnum, IntFlag, unique
+from typing import Tuple
+
+from cryptography.hazmat.primitives import hashes
+from cryptography.hazmat.primitives.asymmetric import ec
+
+Version = Tuple[int, int, int]
 
 
 @unique
@@ -43,6 +47,12 @@ class ERROR(IntEnum):
     ALGORITHM_DISABLED = 0x12
     COMMAND_UNEXECUTED = 0xFF
 
+    def __repr__(self):
+        return "<%s.%s: %s>" % (self.__class__.__name__, self._name_, hex(self))
+
+    def __str__(self):
+        return repr(self)
+
 
 @unique
 class COMMAND(IntEnum):
@@ -114,6 +124,12 @@ class COMMAND(IntEnum):
 
     ERROR = 0x7F
 
+    def __repr__(self):
+        return "<%s.%s: %s>" % (self.__class__.__name__, self._name_, hex(self))
+
+    def __str__(self):
+        return repr(self)
+
 
 @unique
 class ALGORITHM(IntEnum):
@@ -180,6 +196,9 @@ class ALGORITHM(IntEnum):
     AES_CBC = 54
     AES_KWP = 55
 
+    def __str__(self):
+        return repr(self)
+
     def to_curve(self) -> ec.EllipticCurve:
         """Return a Cryptography EC curve instance for a given member.
 
@@ -286,6 +305,9 @@ class LIST_FILTER(IntEnum):
     ALGORITHM = 0x05
     LABEL = 0x06
 
+    def __str__(self):
+        return repr(self)
+
 
 @unique
 class OBJECT(IntEnum):
@@ -301,6 +323,12 @@ class OBJECT(IntEnum):
     SYMMETRIC_KEY = 0x08
     PUBLIC_WRAP_KEY = 0x09
 
+    def __repr__(self):
+        return "<%s.%s: %s>" % (self.__class__.__name__, self._name_, hex(self))
+
+    def __str__(self):
+        return repr(self)
+
 
 @unique
 class OPTION(IntEnum):
@@ -311,6 +339,12 @@ class OPTION(IntEnum):
     ALGORITHM_TOGGLE = 0x04
     FIPS_MODE = 0x05
 
+    def __repr__(self):
+        return "<%s.%s: %s>" % (self.__class__.__name__, self._name_, hex(self))
+
+    def __str__(self):
+        return repr(self)
+
 
 @unique
 class AUDIT(IntEnum):
@@ -320,6 +354,12 @@ class AUDIT(IntEnum):
     ON = 0x01
     FIXED = 0x02
 
+    def __repr__(self):
+        return "<%s.%s: %s>" % (self.__class__.__name__, self._name_, hex(self))
+
+    def __str__(self):
+        return repr(self)
+
 
 @unique
 class FIPS_STATUS(IntEnum):
@@ -329,6 +369,12 @@ class FIPS_STATUS(IntEnum):
     ON = 0x01
     PENDING = 0x03
 
+    def __repr__(self):
+        return "<%s.%s: %s>" % (self.__class__.__name__, self._name_, hex(self))
+
+    def __str__(self):
+        return repr(self)
+
 
 class _enum_prop:
     # Static property for use with enums.
@@ -400,6 +446,12 @@ class CAPABILITY(IntFlag):
     PUBLIC_WRAP_KEY_WRITE = 1 << 0x36
     PUBLIC_WRAP_KEY_DELETE = 1 << 0x37
 
+    def __repr__(self):
+        return "<%s.%s: %s>" % (self.__class__.__name__, self._name_, hex(self))
+
+    def __str__(self):
+        return repr(self)
+
     @_enum_prop
     def NONE(cls) -> "CAPABILITY":
         return cls(0)  # type: ignore
@@ -413,3 +465,9 @@ class ORIGIN(IntFlag):
     GENERATED = 0x01
     IMPORTED = 0x02
     IMPORTED_WRAPPED = 0x10  # Set in combination with GENERATED/IMPORTED
+
+    def __repr__(self):
+        return "<%s.%s: %s>" % (self.__class__.__name__, self._name_, hex(self))
+
+    def __str__(self):
+        return repr(self)
